@@ -11,12 +11,15 @@ UNSPECIFIED = object()
 class Meta:
 
     def __init__(self, obj):
-        self.bound_configs = [BoundConfig(x) for x in get_configs(obj)]
+        self.wrapped_configs = [
+                WrappedConfig(cls(obj))
+                for cls in get_config_classes(obj)
+        ]
         self.param_states = {}
         self.cache_version = 0
         self.load_callbacks = get_load_callbacks(obj).values()
 
-class BoundConfig:
+class WrappedConfig:
 
     def __init__(self, config):
         self.config = config
@@ -24,17 +27,34 @@ class BoundConfig:
         self.is_loaded = False
 
     def __repr__(self):
-        return f'BoundConfig({self.config.__class__.__name__}, is_loaded={self.is_loaded!r})'
+        return f'{self.__class__.__name__}({self.config!r}, is_loaded={self.is_loaded!r})'
 
     def __iter__(self):
         yield from self.layers
 
-    def load(self, obj):
-        self.layers = list(self.config.load(obj))
-        for layer in self.layers:
-            layer.config = self.config
+    def __bool__(self):
+        return bool(self.layers)
+
+    def load(self):
+        self.layers = list(self.config.load())
         self.is_loaded = True
 
+class Log:
+    
+    def __init__(self):
+        self.err = ConfigError()
+
+    def info(self, message, **kwargs):
+        self.err.put_info(message, **kwargs)
+
+    def hint(self, message):
+        if message not in self.err.hints:
+            self.err.hints += message
+
+    def make_error(self, brief):
+        self.err.brief = brief
+        return self.err
+
 def init(obj):
     if hasattr(obj, META_ATTR):
         return False
@@ -44,7 +64,6 @@ def init(obj):
     _load_configs(
             obj,
             predicate=lambda g: g.config.autoload,
-            force_callback=lambda p: p._load_default(obj) is not UNSPECIFIED,
     )
 
     return True
@@ -75,7 +94,7 @@ def reload(obj, config_cls=None):
 def get_meta(obj):
     return getattr(obj, META_ATTR)
 
-def get_configs(obj):
+def get_config_classes(obj):
     try:
         return getattr(obj, CONFIG_ATTR)
     except AttributeError:
@@ -87,8 +106,8 @@ def get_configs(obj):
         err.blame += "{obj!r} has no '{config_attr}' attribute"
         raise err
 
-def get_bound_configs(obj):
-    return get_meta(obj).bound_configs
+def get_wrapped_configs(obj):
+    return get_meta(obj).wrapped_configs
 
 def get_cache_version(obj):
     return get_meta(obj).cache_version
@@ -108,72 +127,47 @@ def get_load_callbacks(obj):
 def get_param_states(obj):
     return get_meta(obj).param_states
 
-def iter_values(obj, getters, default=UNSPECIFIED):
+def iter_values(getters, default=UNSPECIFIED):
     # It's important that this function is a generator.  This allows the `pick` 
     # argument to `param()` to pick, for example, the first value without 
     # having to calculate any subsequent values (which could be expensive).
 
-    configs, locations = [], []
+    log = Log()
     have_value = False
 
+    if not getters:
+        log.info("nowhere to look for values")
+
     for getter in getters:
-        for value in getter.iter_values(configs, locations):
+        for value in getter.iter_values(log):
             have_value = True
             yield getter.cast_value(value)
 
     if default is not UNSPECIFIED:
         have_value = True
         yield default
+    else:
+        log.hint("did you mean to provide a default?")
 
     if not have_value:
-        configs = get_configs(obj)
-        err = ConfigError(
-                "can't find value for parameter",
-                obj=obj,
-                locations=locations,
-                getters=getters,
-        )
-
-        if not configs:
-            err.data.config_attr = CONFIG_ATTR
-            err.blame += "`{obj.__class__.__qualname__}.{config_attr}` is empty"
-            err.blame += "nowhere to look for values"
-
-        elif not locations:
-            from more_itertools import unique_everseen
-            err.blame += lambda e: '\n'.join((
-                "found the following configs, but none yielded any layers:",
-                *map(repr, unique_everseen(configs)),
-            ))
-            err.hints += f"did you forget to call `appcli.load()`?"
-
-        else:
-            err.info += lambda e: '\n'.join((
-                    "searched the following locations:", *(
-                        f'{": ".join(loc)}'
-                        for loc in e.locations
-                    )
-            ))
-            err.hints += "did you mean to provide a default?"
-
-        raise err
+        raise log.make_error("can't find value for parameter")
 
 
-def _load_configs(obj, predicate, force_callback=lambda p: False):
+def _load_configs(obj, predicate):
     meta = get_meta(obj)
-    meta.bound_configs, bound_configs = [], meta.bound_configs
+    meta.wrapped_configs, wrapped_configs = [], meta.wrapped_configs
     meta.cache_version += 1
     updated_configs = []
 
-    # Rebuild the `bound_configs` list from scratch and iterate through the 
+    # Rebuild the `wrapped_configs` list from scratch and iterate through the 
     # configs in reverse order so that each config, when being loaded, can make 
     # use of values loaded by previous configs but not upcoming ones.
-    for bound_config in reversed(bound_configs):
-        if predicate(bound_config):
-            bound_config.load(obj)
-            updated_configs.append(bound_config.config)
+    for wrapped_config in reversed(wrapped_configs):
+        if predicate(wrapped_config):
+            wrapped_config.load()
+            updated_configs.append(wrapped_config.config)
 
-        meta.bound_configs.insert(0, bound_config)
+        meta.wrapped_configs.insert(0, wrapped_config)
         meta.cache_version += 1
 
     for callback in meta.load_callbacks:
