@@ -48,20 +48,20 @@ def test_init_load_reload(obj, init_layers, load_layers, reload_layers):
 
     assert collect_layers(obj) == reload_layers
 
-def test_get_configs():
+def test_get_config_classes():
 
     sentinel = object()
     class Obj:
         __config__ = sentinel
 
     obj = Obj()
-    assert appcli.model.get_configs(obj) is sentinel
+    assert appcli.model.get_config_classes(obj) is sentinel
 
-def test_get_configs_err():
+def test_get_config_classes_err():
     obj = DummyObj()
 
     with pytest.raises(appcli.ScriptError) as err:
-        appcli.model.get_configs(obj)
+        appcli.model.get_config_classes(obj)
 
     assert err.match('object not configured for use with appcli')
     assert err.match(no_templates)
@@ -92,7 +92,7 @@ def test_iter_values(obj, param, getters, default, expected, error):
     kwargs = {'default': eval(default)} if default else {}
 
     with error:
-        values = appcli.model.iter_values(obj, bound_getters, **kwargs)
+        values = appcli.model.iter_values(bound_getters, **kwargs)
         assert list(values) == expected
 
 
